@@ -1,7 +1,6 @@
 """
 main entry point to the program
 """
-import pylogconf.core
 from pytconf import register_main, config_arg_parse_and_launch
 
 from pyflexebs.endpoints.group_default import register_group_default
@@ -19,7 +18,7 @@ def main():
     """
     pyflexebs will enlarge/reduce your ebs volumes in real time
     """
-    pylogconf.core.setup_logging()
+    # pylogconf.core.setup_logging()
     register_all_groups()
     config_arg_parse_and_launch()
 
